.. _apiref:

===============
 API Reference
===============

:Release: |version|
:Date: |today|

.. toctree::
    :maxdepth: 1

    deux
    deux.abstract_models
    deux.authtoken
    deux.authtoken.serializers
    deux.authtoken.views
    deux.constants
    deux.exceptions
    deux.models
    deux.notifications
    deux.oauth2
    deux.oauth2.backends
    deux.oauth2.exceptions
    deux.oauth2.validators
    deux.oauth2.views
    deux.serializers
    deux.services
    deux.strings
    deux.validators
    deux.views
